@@ -1,5 +1,4 @@
-;; -*- lexical-binding: t; -*-
-(require 'spacemacs-theme)
+(require 'spacemacs-common)
 
 (deftheme spacemacs-dark "Spacemacs theme, the dark version")
 
